@@ -36,8 +36,8 @@ class ObsFileCache():
         @param file_path: 文件路径 url|本地目录|本地文件
         @param del_local: 缓存后是否删除本地文件
         """
-        if not os.path.exists(file_path) and not re.match("http", file_path) and not isinstance(file_path, str) \
-                and not isinstance(file_path, dict) and not isinstance(file_path, list) and file_path is not None:
+        if not isinstance(file_path, str) and not isinstance(file_path, dict) and not isinstance(file_path, list) \
+                and file_path is not None and not re.match("http", file_path) and not os.path.exists(file_path) :
             raise FileNotFoundError(file_path)
 
         local_cache_path = '/tmp/%s.%s' % (self.random_str(30), self.random_str(30))
